﻿using Hotline.Share.Dtos.Order;
using Hotline.Share.Enums.Order;
using MapsterMapper;
using Sharing.DaoShu110;
using Sharing.DaoShu110.Dtos;
using Sharing.Province.HuiJu.Send;
using Sharing.Province.Other;
using Sharing.Province.Dtos.Extend;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.Extend;
using Sharing.Share.Enums.DaoShu110;
using XF.Domain.Dependency;
using Sharing.Notifications.HuiJu;
using MediatR;
using System.Linq;

namespace Sharing.Api
{
    /// <summary>
    /// 
    /// </summary>
    public class ProvinceService : IProvinceService, IScopeDependency
    {
        private readonly ISubmitCaseInfoRepository _submitCaseInfoRepository;
        private readonly IMapper _mapper;
        private readonly IMediator _mediator;
        private readonly IPoliceSendChainAlarmDsRepository _policeSendChainAlarmDsRepository;
        private readonly ISubmitVisitInfoRepository _submitVisitInfoRepository;
        private readonly IWaitingPushDataRepository _waitingPushDataRepository;
        private readonly ISubmitCaseProcessRepository _submitCaseProcessRepository;
        private readonly IPoliceSendChainDealDsRepository _policeSendChainDealDsRepository;
        private readonly ISubmitCaseResultRepository _submitCaseResultRepository;
        private readonly IReceiveCaseExtendsRepository _receiveCaseExtendsRepository;
        private readonly IFormEnvironMentRepository _formEnvironMentRepository;
        private readonly IFormTrafficRepository _formTrafficRepository;
        private readonly IFormExpressWayRepository _formExpressWayRepository;
        private readonly IFormMedicalRepository _formMedicalRepository;
        private readonly IFormNetWorktecRepository _formNetWorktecRepository;
        private readonly IFormPostRepository _formPostRepository;
        private readonly IFormReturnexChangeRepository _formReturnexChangeRepository;
        private readonly IFormShamPubRepository _formShamPubRepository;
        private readonly IFormTaxationComplaintRepository _formTaxationComplaintRepository;
        private readonly IFormTaxationConsultingRepository _formTaxationConsultingRepository;
        private readonly IFormMarketRepository _formMarketRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="submitCaseInfoRepository"></param>
        /// <param name="mapper"></param>
        /// <param name="mediator"></param>
        /// <param name="policeSendChainAlarmDsRepository"></param>
        /// <param name="submitVisitInfoRepository"></param>
        /// <param name="waitingPushDataRepository"></param>
        /// <param name="submitCaseProcessRepository"></param>
        /// <param name="policeSendChainDealDsRepository"></param>
        /// <param name="submitCaseResultRepository"></param>
        /// <param name="receiveCaseExtendsRepository"></param>
        /// <param name="formMarketRepository"></param>
        /// <param name="formEnvironMentRepository"></param>
        /// <param name="formTaxationConsultingRepository"></param>
        /// <param name="formTrafficRepository"></param>
        /// <param name="formExpressWayRepository"></param>
        /// <param name="formMedicalRepository"></param>
        /// <param name="formNetWorktecRepository"></param>
        /// <param name="formPostRepository"></param>
        /// <param name="formReturnexChangeRepository"></param>
        /// <param name="formShamPubRepository"></param>
        /// <param name="formTaxationComplaintRepository"></param>
        public ProvinceService(ISubmitCaseInfoRepository submitCaseInfoRepository, IMapper mapper, IMediator mediator
            , IPoliceSendChainAlarmDsRepository policeSendChainAlarmDsRepository, ISubmitVisitInfoRepository submitVisitInfoRepository
            , IWaitingPushDataRepository waitingPushDataRepository, ISubmitCaseProcessRepository submitCaseProcessRepository
            , IPoliceSendChainDealDsRepository policeSendChainDealDsRepository, ISubmitCaseResultRepository submitCaseResultRepository
          , IReceiveCaseExtendsRepository receiveCaseExtendsRepository, IFormMarketRepository formMarketRepository
            , IFormEnvironMentRepository formEnvironMentRepository, IFormTaxationConsultingRepository formTaxationConsultingRepository
            , IFormTrafficRepository formTrafficRepository, IFormExpressWayRepository formExpressWayRepository
            , IFormMedicalRepository formMedicalRepository, IFormNetWorktecRepository formNetWorktecRepository
            , IFormPostRepository formPostRepository, IFormReturnexChangeRepository formReturnexChangeRepository
            , IFormShamPubRepository formShamPubRepository, IFormTaxationComplaintRepository formTaxationComplaintRepository
           )
        {
            _submitCaseInfoRepository = submitCaseInfoRepository;
            _mapper = mapper;
            _mediator = mediator;
            _policeSendChainAlarmDsRepository = policeSendChainAlarmDsRepository;
            _submitVisitInfoRepository = submitVisitInfoRepository;
            _waitingPushDataRepository = waitingPushDataRepository;
            _submitCaseProcessRepository = submitCaseProcessRepository;
            _policeSendChainDealDsRepository = policeSendChainDealDsRepository;
            _submitCaseResultRepository = submitCaseResultRepository;
            _receiveCaseExtendsRepository = receiveCaseExtendsRepository;
            _formEnvironMentRepository = formEnvironMentRepository;
            _formTrafficRepository = formTrafficRepository;
            _formExpressWayRepository = formExpressWayRepository;
            _formMedicalRepository = formMedicalRepository;
            _formNetWorktecRepository = formNetWorktecRepository;
            _formPostRepository = formPostRepository;
            _formReturnexChangeRepository = formReturnexChangeRepository;
            _formShamPubRepository = formShamPubRepository;
            _formTaxationComplaintRepository = formTaxationComplaintRepository;
            _formTaxationConsultingRepository = formTaxationConsultingRepository;
            _formMarketRepository = formMarketRepository;
        }

        /// <summary>
        /// 工单创建数据处理
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task<SubmitCaseInfo> InitData(OrderDto dto)
        {
            var submitCaseInfo = _mapper.Map<SubmitCaseInfo>(dto);

            //如果省和市相同直接用市，也就是直辖市的情况

            submitCaseInfo.CaseAddress = dto.FullAddress;

            //处理诉求渠道
            submitCaseInfo.CaseSource = dto.SourceChannel;

            //处理性别
            switch (dto.FromGender)
            {
                case EGender.Female:
                    submitCaseInfo.AppLicantSex = "0";
                    break;
                case EGender.Male:
                    submitCaseInfo.AppLicantSex = "1";
                    break;
                case EGender.Unknown:
                    submitCaseInfo.AppLicantSex = "2";
                    break;
                default:
                    submitCaseInfo.AppLicantSex = "2";
                    break;
            }

            //处理证件类型
            switch (dto.LicenceTypeCode)
            {
                case "10":
                    submitCaseInfo.CertifiCateType = "10";
                    break;
                case "40":
                    submitCaseInfo.CertifiCateType = "20";
                    break;
                case "55":
                    submitCaseInfo.CertifiCateType = "30";
                    break;
                case "57":
                    submitCaseInfo.CertifiCateType = "40";
                    break;
                default:
                    submitCaseInfo.CertifiCateType = "50";
                    break;
            }

            //处理受理类型
            switch (dto.AcceptType)
            {
                case EAcceptType.Consult:
                    submitCaseInfo.CaseType = "10";
                    break;
                case EAcceptType.Suggest:
                    submitCaseInfo.CaseType = "15";
                    break;
                case EAcceptType.SeekHelp:
                    submitCaseInfo.CaseType = "20";
                    break;
                case EAcceptType.Praise:
                    submitCaseInfo.CaseType = "25";
                    break;
                case EAcceptType.Report:
                    submitCaseInfo.CaseType = "30";
                    break;
                case EAcceptType.Complain:
                    submitCaseInfo.CaseType = "35";
                    break;
                case EAcceptType.Other:
                    submitCaseInfo.CaseType = "40";
                    break;
                default:
                    submitCaseInfo.CaseType = "40";
                    break;
            }

            //处理紧急程度
            switch (dto.EmergencyLevel)
            {
                case EEmergencyLevel.QuiteEmergency:
                    submitCaseInfo.CaseIsUrgent = "10";
                    break;
                case EEmergencyLevel.Emergency:
                    submitCaseInfo.CaseIsUrgent = "20";
                    break;
                default:
                    submitCaseInfo.CaseIsUrgent = "30";
                    break;
            }

            submitCaseInfo.Id = await _submitCaseInfoRepository.AddAsync(submitCaseInfo);

            //需要判断是否需要往110推送
            //写入110本地数据库
            await InitPoliceSendChainAlarmDs(dto, submitCaseInfo.CaseAddress);

            return submitCaseInfo;
        }

        /// <summary>
        /// 服务工单回访评价
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task SubmitVisitInfo(PublishVisitDto dto)
        {
            var data = _mapper.Map<SubmitVisitInfo>(dto);
            switch (dto.VisitType)
            {
                case EVisitType.ArtificialVisit:
                    data.VisitType = "DH";
                    break;
                case EVisitType.SmsVisit:
                    data.VisitType = "DX";
                    break;
                case EVisitType.WebVisit:
                    data.VisitType = "WZ";
                    break;
                case EVisitType.WeChatVisit:
                    data.VisitType = "WX";
                    break;
                case EVisitType.AppVisit:
                    data.VisitType = "AP";
                    break;
                default:
                    break;
            }
            //将上报信息写入本地库
            data.Id = await _submitVisitInfoRepository.AddAsync(data);

            //将待推送数据写入待推送表
            WaitingPushData pushData = new()
            {
                ServiceInterface = "SubmitVisitInfo",
                Data = System.Text.Json.JsonSerializer.Serialize(data),
                Priority = 0,
                PushUrl = "submit_visit_info",
                Method = HttpMethods.Post
            };
            await _waitingPushDataRepository.AddAsync(pushData);

            //组装110数据
            if (dto.Order.Source == ESource.Police110)
            {
                var checkData = await _policeSendChainDealDsRepository.GetAsync(p => p.AlarmReceiptNumber == dto.Order.No110 && p.DisposalType == (int)EDisposalType.Visit);
                if (checkData == null)
                {
                    checkData = new()
                    {
                        AlarmReceiptNumber = dto?.Order?.No110,
                        RevisitTime = dto.VisitTime,
                        CheckingContent = dto.VisitRemark,
                        VisitContent = dto.VisitRemark,
                        //  VisitResult = SubjectResultSatifyCode,
                        DisposalType = 3
                    };
                    await _policeSendChainDealDsRepository.AddAsync(checkData);
                }
                else
                {
                    checkData.AlarmReceiptNumber = dto?.Order?.No110;
                    checkData.RevisitTime = dto.VisitTime;
                    checkData.CheckingContent = dto.VisitRemark;
                    checkData.VisitContent = dto.VisitRemark;
                    //  checkData.VisitResult = SubjectResultSatifyCode;
                    await _policeSendChainDealDsRepository.UpdateAsync(checkData);
                }

            }
        }

        /// <summary>
        /// 服务工单处理
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task SubmitCaseProcess(OrderFlowDto dto)
        {
            var data = _mapper.Map<SubmitCaseProcess>(dto);

            data.TacheName = "70:" + data.DeptName;
            //将上报信息写入本地库
            data.Id = await _submitCaseProcessRepository.AddAsync(data);

            //将待推送数据写入待推送表
            WaitingPushData pushData = new()
            {
                ServiceInterface = "SubmitCaseProcess",
                Data = System.Text.Json.JsonSerializer.Serialize(data),
                Priority = 0,
                PushUrl = "submit_case_process",
                Method = HttpMethods.Post
            };
            await _waitingPushDataRepository.AddAsync(pushData);

        }

        /// <summary>
        /// 服务工单结果
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task SubmitCaseResult(OrderFlowDto dto)
        {
            var data = _mapper.Map<SubmitCaseResult>(dto);
            data.ConcactType = "40";
            data.FinishType = "1";
            data.HandleTimeLong = 0;
            //将上报信息写入本地库
            data.Id = await _submitCaseResultRepository.AddAsync(data);

            //将待推送数据写入待推送表
            WaitingPushData pushData = new()
            {
                ServiceInterface = "SubmitCaseResult",
                Data = System.Text.Json.JsonSerializer.Serialize(data),
                Priority = 0,
                PushUrl = "submit_case_result",
                Method = HttpMethods.Post
            };
            await _waitingPushDataRepository.AddAsync(pushData);

            //判断如果是110过来的数据，就组装数据
            //组装110
            if (dto.Order.Source == ESource.Police110)
            {
                await InitPoliceSendChainDealDs(dto);
            }
        }

        /// <summary>
        /// 服务工单拓展信息
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task SubmitCaseExtends(OrderDto dto)
        {
            //工单类型
            string formType = "";
            switch (dto.OrderType)
            {
                case EOrderType.Common:
                    break;
                case EOrderType.MarketSupervisionBy12315:
                    formType = "scjgj";
                    break;
                default:
                    break;
            }

            //扩展主表信息
            ReceiveCaseExtends receiveCaseExtends = new()
            {
                CaseSerial = dto.ToProvinceNo,
                FormType = formType,
                SyncState = "0",
                Direction = "1"
            };

            //将上报信息写入本地库  
            var id = await _receiveCaseExtendsRepository.AddAsync(receiveCaseExtends);

            FormMarket dtoscjgj = new();
            //处理扩展信息
            switch (formType.ToLower())
            {
                case "yl"://医疗表单
                    //转换数据
                    var dtoyl = _mapper.Map<FormMedical>(dto);
                    dtoyl.RCEId = id;
                    //添加数据
                    await _formMedicalRepository.AddAsync(dtoyl);
                    break;
                case "zwfw"://四川政务服务网技术工单
                    //转换数据
                    var dtozwfw = _mapper.Map<FormNetWorktec>(dto);
                    dtozwfw.RCEId = id;
                    //添加数据
                    await _formNetWorktecRepository.AddAsync(dtozwfw);
                    break;
                case "th"://电视购物及商铺购买退换货工单
                    //转换数据
                    var dtoth = _mapper.Map<FormReturnexChange>(dto);
                    dtoth.RCEId = id;
                    //添加数据
                    await _formReturnexChangeRepository.AddAsync(dtoth);
                    break;
                case "gsgl"://高速公路工单
                    //转换数据
                    var dtogsgl = _mapper.Map<FormExpressWay>(dto);
                    dtogsgl.RCEId = id;
                    //添加数据
                    await _formExpressWayRepository.AddAsync(dtogsgl);
                    break;
                case "xjgg"://电视台虚假广告工单
                    //转换数据
                    var dtoxjgg = _mapper.Map<FormShamPub>(dto);
                    dtoxjgg.RCEId = id;
                    //添加数据
                    await _formShamPubRepository.AddAsync(dtoxjgg);
                    break;
                case "swfwsq"://12366热线诉求交办
                    //转换数据
                    var dtoswfwsq = _mapper.Map<FormTaxationComplaint>(dto);
                    dtoswfwsq.RCEId = id;
                    //添加数据
                    await _formTaxationComplaintRepository.AddAsync(dtoswfwsq);
                    break;
                case "swfwzx"://12366热线咨询交办
                    //转换数据
                    var dtoswfwzx = _mapper.Map<FormTaxationConsulting>(dto);
                    dtoswfwzx.RCEId = id;
                    //添加数据
                    await _formTaxationConsultingRepository.AddAsync(dtoswfwzx);
                    break;
                case "jtfwjd"://12328服务监督
                    //转换数据
                    var dtojtfwjd = _mapper.Map<FormTraffic>(dto);
                    dtojtfwjd.RCEId = id;
                    //添加数据
                    await _formTrafficRepository.AddAsync(dtojtfwjd);
                    break;
                case "yzxf"://邮政业消费者申诉
                    //转换数据
                    var dtoyzxf = _mapper.Map<FormPost>(dto);
                    dtoyzxf.RCEId = id;
                    //添加数据
                    await _formPostRepository.AddAsync(dtoyzxf);
                    break;
                case "hbjb"://环保举报业务
                    //转换数据
                    var dtohbjb = _mapper.Map<FormEnvironMent>(dto);
                    dtohbjb.RCEId = id;
                    //添加数据
                    await _formEnvironMentRepository.AddAsync(dtohbjb);
                    break;
                case "scjgj"://12315个性化表单
                    //转换数据
                    switch (dto.AcceptType)
                    {
                        case EAcceptType.Consult:
                            dtoscjgj.Rqsttypy = "10";
                            break;
                        case EAcceptType.Report:
                            dtoscjgj = _mapper.Map<FormMarket>(dto.OrderReport);
                            dtoscjgj.Rqsttypy = "25";
                            break;
                        case EAcceptType.Complain:
                            dtoscjgj = _mapper.Map<FormMarket>(dto.OrderComplain);
                            dtoscjgj.Rqsttypy = "20";
                            string str = "";
                            foreach (var item in dto.OrderComplain.ComplainTypes)
                                str += item.Name + ",";
                            dtoscjgj.AppealContent = str;
                            break;
                        default:
                            break;
                    }

                    dtoscjgj.HandDepCode = dto.AcceptorOrgCode;
                    dtoscjgj.HandDep = dto.AcceptorOrgName;
                    dtoscjgj.Zxgh = dto.AcceptorStaffNo;
                    dtoscjgj.AccregperId = dto.AcceptorId;
                    dtoscjgj.AccregperName = dto.AcceptorName;
                    dtoscjgj.RegTime = Convert.ToDateTime(dto.CreationTime);
                    dtoscjgj.CmTime = dto.StartTime;
                    dtoscjgj.RCEId = id;
                    //添加数据
                    await _formMarketRepository.AddAsync(dtoscjgj);
                    break;
                default:
                    break;
            }

            SubmitCaseExtendsInfo submitCaseExtendsInfo = new()
            {
                CaseSerial = dto.ToProvinceNo,
                FormType = formType,
                FormMarket = _mapper.Map<FormMarketInfo>(dtoscjgj)
            };
            //组装数据
            SubmitCaseExtendsInfoId submitCaseExtendsInfoId = new()
            {
                Id = id,
                Info = submitCaseExtendsInfo
            };

            //信息上报
            await _mediator.Publish(new SubmitCaseExtendsNotification(Newtonsoft.Json.JsonConvert.SerializeObject(submitCaseExtendsInfoId)));
        }

        #region 私有方法

        #region 组装110数据
        /// <summary>
        /// 组装110数据，12345警情工单推送到110
        /// </summary>
        /// <param name="orderDto"></param>
        /// <param name="CaseAddress"></param>
        /// <returns></returns>
        private async Task InitPoliceSendChainAlarmDs(OrderDto orderDto, string CaseAddress)
        {
            PoliceSendChainAlarmDs policeSend = new()
            {
                SerialNumber = orderDto.No110,
                AlarmReceiptNumber = orderDto.No110,
                RegisterNo = orderDto.AcceptorStaffNo,
                CallPoliceNumber = orderDto.FromPhone,
                CallPoliceName = orderDto.FromName,
                PhoneNumber = orderDto.Contact,
                CallPoliceContent = orderDto.Content,
                PoliceTypeCode = "",
                PoliceTypeName = "",
                JurisdictionalUnitCode = "511500000000",
                JurisdictionalUnitName = "宜宾市公安局",
                JurisdictionalUnitNumber = "0831110",
                AlarmReceivingUnitCode = "",
                AlarmReceivingUnitName = "",
                CallPoliceTime = Convert.ToDateTime(orderDto.CreationTime),
                PushTime = DateTime.Now,
                AlarmReceptionType = "0",
                AreaCode = orderDto.AreaCode,
                CallPoliceAddress = CaseAddress,
                OrderId = orderDto.Id
            };
            //查询是否有此工单，如果没有新增此工单
            var data = await _policeSendChainAlarmDsRepository.GetAsync(p => p.OrderId == orderDto.Id);
            if (data == null)
                await _policeSendChainAlarmDsRepository.AddAsync(policeSend);
        }

        /// <summary>
        /// 110的非警情工单获取办理信息
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        private async Task InitPoliceSendChainDealDs(OrderFlowDto dto)
        {
            var data = await _policeSendChainDealDsRepository.GetAsync(p => p.AlarmReceiptNumber == dto.Order.No110 && p.DisposalType == (int)EDisposalType.OrderFiled);
            if (data == null)
            {
                data = new()
                {
                    AlarmReceiptNumber = dto.Order.No110,
                    FeedbackTime = dto.Order.ActualHandleTime,
                    DisposalSituation = dto.Order.ActualOpinion,
                    ResultDescription = dto.Order.ActualOpinion,
                    FeedbackPersonNumber = dto.Order.ActualHandlerId,
                    FeedbackPersonName = dto.Order.ActualHandlerName,
                    FeedbackUnitCode = dto.Order.ActualHandleOrgCode,
                    FeedbackUnitName = dto.Order.ActualHandleOrgName,
                    WarehousingTime = DateTime.Now,
                    DisposalType = 1
                };
                await _policeSendChainDealDsRepository.AddAsync(data);
            }
            else
            {
                data.AlarmReceiptNumber = dto.Order.No110;
                data.FeedbackTime = dto.Order.ActualHandleTime;
                data.DisposalSituation = dto.Order.ActualOpinion;
                data.ResultDescription = dto.Order.ActualOpinion;
                data.FeedbackPersonNumber = dto.Order.ActualHandlerId;
                data.FeedbackPersonName = dto.Order.ActualHandlerName;
                data.FeedbackUnitCode = dto.Order.ActualHandleOrgCode;
                data.FeedbackUnitName = dto.Order.ActualHandleOrgName;
                data.WarehousingTime = DateTime.Now;
                await _policeSendChainDealDsRepository.UpdateAsync(data);
            }
        }

        #endregion

        #endregion
    }
}
