﻿using Hotline.Share.Dtos.Knowledge;
using Hotline.Share.Dtos.Order;
using Hotline.Share.Enums.Order;
using Mapster;
using Sharing.DaoShu110.Dtos;
using Sharing.Province.Extend;
using Sharing.Province.HuiJu.Send;
using Sharing.Province.XieTong.Knowledge;
using Sharing.Province.XieTong.Receive;
using Sharing.Province.XieTong.Send;
using System.Collections.Generic;

namespace Sharing.Application.Mappers
{
    public class MapperConfigs : IRegister
    {
        public void Register(TypeAdapterConfig config)
        {
            config.ForType<KnowledgeSendDto, GetKnowledgeInfoSend>()
            .Map(d => d.CreatDate, x => x.CreatDate == null ? null : x.CreatDate.Value.ToString("yyyy-MM-dd HH:mm:ss"))
            .Map(d => d.BeginDate, x => x.BeginDate == null ? null : x.BeginDate.Value.ToString("yyyy-MM-dd HH:mm:ss"))
            .Map(d => d.DisableDate, x => x.DisableDate == null ? null : x.DisableDate.Value.ToString("yyyy-MM-dd HH:mm:ss"))
          ;

            config.ForType<GetKnowledgeInfoUpdate, GetKnowledgeInfoSend>()
            .Map(d => d.CreatDate, x => x.CreatDate == null ? null : x.CreatDate.Value.ToString("yyyy-MM-dd HH:mm:ss"))
            .Map(d => d.BeginDate, x => x.BeginDate == null ? null : x.BeginDate.Value.ToString("yyyy-MM-dd HH:mm:ss"))
            .Map(d => d.DisableDate, x => x.DisableDate == null ? null : x.DisableDate.Value.ToString("yyyy-MM-dd HH:mm:ss"))
          ;

            config.ForType<OrderDto, SubmitCaseInfo>()
                .Ignore(d => d.Id)
                .Map(d => d.OrderID, x => x.Id)
                .Map(d => d.CaseTitle, x => x.Title)
                .Map(d => d.CaseRegister, x => x.AcceptorName)
                .Map(d => d.CaseRegisterNo, x => x.AcceptorStaffNo)
                .Map(d => d.CaseDate, x => Convert.ToDateTime(x.CreationTime))
                .Map(d => d.PhoneNumber, x => x.Contact)
                .Map(d => d.AppLicantName, x => x.FromName)
                .Map(d => d.AppLicantAge, x => x.AgeRangeCode)
                .Map(d => d.AppLicantId, x => x.LicenceNo)
                .Map(d => d.CaseAccord, x => x.Hotspot.ProvinceCode)
                .Map(d => d.CaseContent, x => x.Content)
                .Map(d => d.CaseProcessType, x => Convert.ToInt32(x.ProcessType))
                .Map(d => d.CaseIsSecrect, x => x.IsSecret)
                .Map(d => d.CaseIsVisit, x => x.ProcessType == Hotline.Share.Enums.Order.EProcessType.Zhiban ? "0" : "1")
                .Map(d => d.EventDate, x => x.IncidentTime == null ? null : x.IncidentTime.Value.ToString("yyyy-MM-dd HH:mm:ss"))
                .Map(d => d.PushType, x => x.PushTypeCode)
                .Map(d => d.AreaCode, x => x.AreaCode)
               .Map(d => d.CaseSerial, x => x.ToProvinceNo)
              ;

            config.ForType<OrderFlowDto, SubmitCaseProcess>()
           .Map(d => d.CaseSerial, x => x.Order.ToProvinceNo)
            .Map(d => d.DeptName, x => x.WorkflowTrace.OrgName)
            .Map(d => d.ProcessTime, x => x.WorkflowTrace.CompleteTime == null ? null : x.WorkflowTrace.CompleteTime.Value.ToString("yyyy-MM-dd HH:mm:ss"))
            .Map(d => d.ProcessName, x => x.WorkflowTrace.UserName)
            .Map(d => d.ProcessNote, x => x.WorkflowTrace.Opinion)
            .Map(d => d.EndAreaCode, x => x.WorkflowTrace.OrgAreaCode)
            .Map(d => d.EndAreaName, x => x.WorkflowTrace.OrgAreaName)
            .Map(d => d.CaseId, x => x.WorkflowTrace.Id)
            .Map(d => d.AreaCode, x => x.Order.AreaCode)
              ;

            config.ForType<OrderFlowDto, GetCaseProcessReceive>()
          .Map(d => d.CaseSerial, x => x.Order.FromProvinceNo)
           .Map(d => d.DeptName, x => x.WorkflowTrace.OrgName)
           .Map(d => d.ProcessTime, x => x.WorkflowTrace.CompleteTime == null ? null : x.WorkflowTrace.CompleteTime.Value.ToString("yyyy-MM-dd HH:mm:ss"))
           .Map(d => d.ProcessName, x => x.WorkflowTrace.UserName)
           .Map(d => d.ProcessNote, x => x.WorkflowTrace.Opinion)
           .Map(d => d.EndAreaCode, x => x.WorkflowTrace.OrgAreaCode)
           .Map(d => d.EndAreaName, x => x.WorkflowTrace.OrgAreaName)
           .Map(d => d.TrowGuid, x => x.WorkflowTrace.Id)
            .Map(d => d.AreaCode, x => x.Order.AreaCode)
             ;

            config.ForType<PublishVisitDto, SubmitVisitInfo>()
            .Map(d => d.CaseSerial, x => x.Order.ToProvinceNo)
            ;
            config.ForType<PublishVisitDto, GetVisitInfoReceive>()
            .Map(d => d.CaseSerial, x => x.Order.FromProvinceNo)
            ;

            //汇聚扩展数据--投诉
            config.ForType<OrderComplainDto, FormMarket>()
            .Map(d => d.ApplBasQue, x => x.ComplainClassifyCode)
            .Map(d => d.ApplBasQueName, x => x.ComplainClassify)
            .Map(d => d.Zlh, x => x.PatentNo)
            .Map(d => d.Zlqr, x => x.Patentee)
            .Map(d => d.Fmmc, x => x.PatentName)
            .Map(d => d.Zllx, x => x.PatentTypeCode)
            .Map(d => d.ZllxMc, x => x.PatentType)
            .Map(d => d.Accsce, x => x.BusinessPosition.AreaCode)
            .Map(d => d.Sfdd, x => x.BusinessPosition.FullAddress)
            .Map(d => d.ControversyTime, x => x.OccurrenceTime)
            .Map(d => d.OBType, x => x.ObjectClassifyCode)
            .Map(d => d.OBTypeName, x => x.ObjectClassify)
            .Map(d => d.MdseName, x => x.ObjectClassify)
            .Map(d => d.SaleMode, x => x.SalesModeCode)
            .Map(d => d.DsptType, x => x.ComplainTargetCode)
            .Map(d => d.DsptCode, x => x.ECommercePlatformCode)
            .Map(d => d.DsptName, x => x.ECommercePlatform)
            .Map(d => d.BrandCode, x => x.BrandCode)
            .Map(d => d.BrandName, x => x.Brand)
            .Map(d => d.BIdNo, x => x.ExternalOrderNo)
            .Map(d => d.InvoAm, x => x.Amount)
             .Map(d => d.Jtqdtype, x => x.SalesChannelCode)
             .Map(d => d.Jtqdname, x => x.SalesChannel)
             .Map(d => d.ProdName, x => x.ProductName)
             .Map(d => d.ProdAppNo, x => x.ApprovalNumber)
             .Map(d => d.ProdPatchNo, x => x.ProductBatchNo)
             .Map(d => d.ProdTypeSpf, x => x.ProductStandard)
             .Map(d => d.ProdFty, x => x.Manufacturer)
             .Map(d => d.ProdSalEnt, x => x.SalesEnterprise)
             .Map(d => d.ProdValid, x => x.ProductExpiredTime.ToString())
             .Map(d => d.ProviderAddr, x => x.ConsumerAddress)
             .Map(d => d.Invopt, x => x.EnterpriseName)
             .Map(d => d.UBindType, x => x.IndustryClassifyCode)
             .Map(d => d.UBindTypeName, x => x.IndustryClassify)
             .Map(d => d.EntType, x => x.MarketTypeCode)
             .Map(d => d.EntTypeName, x => x.MarketType)
             //.Map(d => d.ReqUnit, x => x.RegisterPosition.AreaCode)
             .Map(d => d.Addr, x => x.RegisterAddress)
             .Map(d => d.Sjztlxr, x => x.EnterpriseContact)
             .Map(d => d.Nbxh, x => x.UnifiedSocialCreditCode)
             .Map(d => d.RegNo, x => x.RegisterNumber)
             .Map(d => d.CertType, x => x.LicenceTypeCode)
             .Map(d => d.CertTypeName, x => x.LicenceType)
             .Map(d => d.CertNo, x => x.LicenceNo)
             .Map(d => d.ReveType, x => x.IdentityTypeCode)
             .Map(d => d.ReveTypeName, x => x.IdentityType)
             .Map(d => d.Nationality, x => x.NationalityCode)
             .Map(d => d.NationalityName, x => x.Nationality)
             .Map(d => d.Folk, x => x.NationCode)
             .Map(d => d.FolkName, x => x.Nation)
             .Map(d => d.Peride, x => x.IdentityCode)
             .Map(d => d.PerideName, x => x.Identity)
             .Map(d => d.ProviderMail, x => x.Email)
             .Map(d => d.Qtlxfs, x => x.OtherContact)
            ;
            //汇聚扩展数据--举报
            config.ForType<OrderReportDto, FormMarket>()
            .Map(d => d.ApplBasQue, x => x.ReportClassifyCode)
            .Map(d => d.ApplBasQueName, x => x.ReportClassify)
            .Map(d => d.Zlh, x => x.PatentNo)
            .Map(d => d.Zlqr, x => x.Patentee)
            .Map(d => d.Fmmc, x => x.PatentName)
            .Map(d => d.Zllx, x => x.PatentTypeCode)
            .Map(d => d.ZllxMc, x => x.PatentType)
            .Map(d => d.OBType, x => x.ObjectClassifyCode)
            .Map(d => d.OBTypeName, x => x.ObjectClassify)
            .Map(d => d.MdseName, x => x.ObjectClassify)
            .Map(d => d.SaleMode, x => x.SalesModeCode)
            .Map(d => d.DsptType, x => x.ReportTargetCode)
            .Map(d => d.DsptCode, x => x.ECommercePlatformCode)
            .Map(d => d.DsptName, x => x.ECommercePlatform)
            .Map(d => d.BrandCode, x => x.BrandCode)
            .Map(d => d.BrandName, x => x.Brand)
            .Map(d => d.BIdNo, x => x.ExternalOrderNo)
            .Map(d => d.InvoAm, x => x.Amount)
             .Map(d => d.Jtqdtype, x => x.SalesChannelCode)
             .Map(d => d.Jtqdname, x => x.SalesChannel)
             .Map(d => d.ProdName, x => x.ProductName)
             .Map(d => d.ProdAppNo, x => x.ApprovalNumber)
             .Map(d => d.ProdPatchNo, x => x.ProductBatchNo)
             .Map(d => d.ProdTypeSpf, x => x.ProductStandard)
             .Map(d => d.ProdFty, x => x.Manufacturer)
             .Map(d => d.ProdSalEnt, x => x.SalesEnterprise)
             .Map(d => d.ProdValid, x => x.ProductExpiredTime.ToString())
             .Map(d => d.ProviderAddr, x => x.ConsumerAddress)
             .Map(d => d.Invopt, x => x.EnterpriseName)
             .Map(d => d.UBindType, x => x.IndustryClassifyCode)
             .Map(d => d.UBindTypeName, x => x.IndustryClassify)
             .Map(d => d.EntType, x => x.MarketTypeCode)
             .Map(d => d.EntTypeName, x => x.MarketType)
                   //.Map(d => d.ReqUnit, x => x.RegisterPosition.AreaCode)
              .Map(d => d.Addr, x => x.RegisterAddress)
             .Map(d => d.Sjztlxr, x => x.EnterpriseContact)
             .Map(d => d.Nbxh, x => x.UnifiedSocialCreditCode)
             .Map(d => d.RegNo, x => x.RegisterNumber)
             .Map(d => d.CertType, x => x.LicenceTypeCode)
             .Map(d => d.CertTypeName, x => x.LicenceType)
             .Map(d => d.CertNo, x => x.LicenceNo)
             .Map(d => d.ReveType, x => x.IdentityTypeCode)
             .Map(d => d.ReveTypeName, x => x.IdentityType)
             .Map(d => d.Nationality, x => x.NationalityCode)
             .Map(d => d.NationalityName, x => x.Nationality)
             .Map(d => d.Folk, x => x.NationCode)
             .Map(d => d.FolkName, x => x.Nation)
             .Map(d => d.Peride, x => x.IdentityCode)
             .Map(d => d.PerideName, x => x.Identity)
             .Map(d => d.ProviderMail, x => x.Email)
             .Map(d => d.Qtlxfs, x => x.OtherContact)
            ;

            config.ForType<ReceiveCaseInfo, OrderDto>()
           .Map(d => d.FromProvinceNo, x => x.CaseSerial)
           .Map(d => d.Title, x => x.CaseTitle)
           .Map(d => d.AcceptorName, x => x.CaseRegister)
           .Map(d => d.AcceptorStaffNo, x => x.CaseRegisterNo)
           .Map(d => d.CreationTime, x => x.CaseDate)
           .Map(d => d.Contact, x => x.PhoneNumber)
           .Map(d => d.FromName, x => x.AppLicantName)
           .Map(d => d.AgeRangeCode, x => x.AppLicantAge)
           .Map(d => d.LicenceNo, x => x.AppLicantId)
           .Map(d => d.Hotspot.ProvinceCode, x => x.CaseAccord)
           .Map(d => d.Content, x => x.CaseContent)
           .Map(d => d.ProcessType, x => x.CaseProcessType)
           .Map(d => d.IsSecret, x => x.CaseIsSecrect == "1" ? true : false)
           .Map(d => d.IsPublicity, x => x.CaseIsPublic == "1" ? true : false)
           .Map(d => d.ExpiredTimeProvince,x => x.TfdBackTimeBf)
           .Map(d => d.AreaCode, x => x.AreaCode)
           .Map(d=>d.Street,x=>x.CaseAddress)
           .Map(d=>d.IncidentTime,x=>x.EventDate)
           .Map(d => d.SourceChannel,x=>x.CaseSource)
             ;



          
            //以下未完全转换
            config.ForType<OrderFlowDto, SubmitCaseResult>()
           .Map(d => d.CaseSerial, x => x.Order.ToProvinceNo)
           .Map(d => d.DeptName, x => x.Order.ActualHandleOrgName)
           .Map(d => d.FinishTime, x => x.Order.ActualHandleTime)
           .Map(d => d.FinishName, x => x.Order.ActualHandlerName)
           .Map(d => d.FinishNote, x => x.Order.ActualOpinion)
           .Map(d => d.EndDept, x => x.Order.ActualHandleOrgName)
           .Map(d => d.EndName, x => x.Order.ActualHandlerName)
           .Map(d => d.SendTime, x => x.Order.Workflow.AssignTime == null ? null : x.Order.Workflow.AssignTime.ToString("yyyy-MM-dd HH:mm:ss"))//需要确认
           .Map(d => d.FdBack, x => x.Order.ActualOpinion)
           .Map(d => d.AreaCode, x => x.Order.AreaCode)
           .Map(d => d.EndAreaCode, x => x.Order.ActualHandleOrgAreaCode)
           .Map(d => d.EndAreaName, x => x.Order.ActualHandleOrgAreaName)
           .Map(d => d.SignTimeBf, x => x.Order.ExpiredTime)
           .Map(d => d.SignTime, x => x.Order.StartTime)//缺少签收时间
           .Map(d => d.FdBackTimeBf, x => x.Order.ExpiredTime)
           .Map(d => d.FdBackTime, x => x.Order.ActualHandleTime)
             ;

            config.ForType<OrderFlowDto, GetCaseResultReceive>()
           .Map(d => d.CaseSerial, x => x.Order.ToProvinceNo)
           .Map(d => d.DeptName, x => x.Order.ActualHandleOrgName)
           .Map(d => d.FinishTime, x => x.Order.ActualHandleTime)
           .Map(d => d.FinishName, x => x.Order.ActualHandlerName)
           .Map(d => d.FinishNote, x => x.Order.ActualOpinion)
           .Map(d => d.EndDept, x => x.Order.ActualHandleOrgName)
           .Map(d => d.EndName, x => x.Order.ActualHandlerName)
           .Map(d => d.SendTime, x => x.Order.Workflow.AssignTime == null ? null : x.Order.Workflow.AssignTime.ToString("yyyy-MM-dd HH:mm:ss"))//需要确认
           .Map(d => d.FdBack, x => x.Order.ActualOpinion)
           .Map(d => d.AreaCode, x => x.Order.AreaCode)
           .Map(d => d.EndAreaCode, x => x.Order.ActualHandleOrgAreaCode)
           .Map(d => d.EndAreaName, x => x.Order.ActualHandleOrgAreaName)
           //.Map(d => d.SignTimeBf, x => x.Order.ExpiredTime)
           //.Map(d => d.SignTime, x => x.Order.StartTime)//缺少签收时间
           //.Map(d => d.FdBackTimeBf, x => x.Order.ExpiredTime)
           //.Map(d => d.FdBackTime, x => x.Order.ActualHandleTime)

            ;


        }

    }
}
