﻿using DotNetCore.CAP;
using Hotline.Share.Dtos.Order;
using Hotline.Share.Enums.Order;
using MapsterMapper;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Sharing.Province.Dtos;
using Sharing.Province.Dtos.XieTong.Receive;
using Sharing.Province.Extend;
using Sharing.Province.XieTong.Receive;
using Sharing.Share.Dtos;
using Sharing.Share.Dtos.Extend;
using Sharing.WebCore;

namespace Sharing.Province.Controllers
{

    /// <summary>
    /// 下行，省平台调用
    /// </summary>
    public class ReceiveController : BaseController
    {
        #region 注入
        private readonly IMapper _mapper;
        private readonly ICapPublisher _capPublisher;
        private readonly IReceiveCaseInfoRepository _receiveCaseInfoRepository;
        private readonly IGetCaseBackResultRepository _getCaseBackResultRepository;
        private readonly IDelayCaseResultRepository _delayCaseResultRepository;
        private readonly ISupplyCaseInfoRepository _supplyCaseInfoRepository;
        private readonly IRevokeCaseInfoRepository _revokeCaseInfoRepository;
        private readonly IRemindCaseInfoRepository _remindCaseInfoRepository;
        private readonly ISendWarnInfoRepository _sendWarnInfoRepository;
        private readonly ISendSuperviseInfoRepository _sendSuperviseInfoRepository;
        private readonly IScreenCaseResultReceiveRepository _screenCaseResultReceiveRepository;
        private readonly ISendCaseEvlResultRepository _sendCaseEvlResultRepository;
        private readonly IGetCaseReultSendRepository _getCaseReultSendRepository;
        private readonly IGetVisitInfoSendRepository _getVisitInfoSendRepository;
        private readonly IFormEnvironMentRepository _formEnvironMentRepository;
        private readonly IFormTrafficRepository _formTrafficRepository;
        private readonly IFormExpressWayRepository _formExpressWayRepository;
        private readonly IFormMedicalRepository _formMedicalRepository;
        private readonly IFormNetWorktecRepository _formNetWorktecRepository;
        private readonly IFormPostRepository _formPostRepository;
        private readonly IFormReturnexChangeRepository _formReturnexChangeRepository;
        private readonly IFormShamPubRepository _formShamPubRepository;
        private readonly IFormTaxationComplaintRepository _formTaxationComplaintRepository;
        private readonly IFormTaxationConsultingRepository _formTaxationConsultingRepository;
        private readonly IReceiveCaseExtendsRepository _receiveCaseExtendsRepository;


        /// <summary>
        /// 
        /// </summary>
        /// <param name="mapper"></param>
        /// <param name="capPublisher"></param>
        /// <param name="receiveCaseInfoRepository"></param>
        /// <param name="getCaseBackResultRepository"></param>
        /// <param name="delayCaseResultRepository"></param>
        /// <param name="supplyCaseInfoRepository"></param>
        /// <param name="revokeCaseInfoRepository"></param>
        /// <param name="remindCaseInfoRepository"></param>
        /// <param name="sendWarnInfoRepository"></param>
        /// <param name="sendSuperviseInfoRepository"></param>
        /// <param name="screenCaseResultReceiveRepository"></param>
        /// <param name="sendCaseEvlResultRepository"></param>
        /// <param name="getCaseReultSendRepository"></param>
        /// <param name="getVisitInfoSendRepository"></param>
        /// <param name="formEnvironMentRepository"></param>
        /// <param name="formTrafficRepository"></param>
        /// <param name="formExpressWayRepository"></param>
        /// <param name="formMedicalRepository"></param>
        /// <param name="formNetWorktecRepository"></param>
        /// <param name="formPostRepository"></param>
        /// <param name="formReturnexChangeRepository"></param>
        /// <param name="formShamPubRepository"></param>
        /// <param name="formTaxationComplaintRepository"></param>
        /// <param name="formTaxationConsultingRepository"></param>
        /// <param name="receiveCaseExtendsRepository"></param>
        public ReceiveController(IMapper mapper, ICapPublisher capPublisher, IReceiveCaseInfoRepository receiveCaseInfoRepository,
            IGetCaseBackResultRepository getCaseBackResultRepository, IDelayCaseResultRepository delayCaseResultRepository
            , ISupplyCaseInfoRepository supplyCaseInfoRepository, IRevokeCaseInfoRepository revokeCaseInfoRepository
            , IRemindCaseInfoRepository remindCaseInfoRepository, ISendWarnInfoRepository sendWarnInfoRepository
            , ISendSuperviseInfoRepository sendSuperviseInfoRepository, IScreenCaseResultReceiveRepository screenCaseResultReceiveRepository
            , ISendCaseEvlResultRepository sendCaseEvlResultRepository, IGetCaseReultSendRepository getCaseReultSendRepository
            , IGetVisitInfoSendRepository getVisitInfoSendRepository, IFormEnvironMentRepository formEnvironMentRepository
            , IFormTrafficRepository formTrafficRepository, IFormExpressWayRepository formExpressWayRepository
            , IFormMedicalRepository formMedicalRepository, IFormNetWorktecRepository formNetWorktecRepository
            , IFormPostRepository formPostRepository, IFormReturnexChangeRepository formReturnexChangeRepository
            , IFormShamPubRepository formShamPubRepository, IFormTaxationComplaintRepository formTaxationComplaintRepository
            , IFormTaxationConsultingRepository formTaxationConsultingRepository, IReceiveCaseExtendsRepository receiveCaseExtendsRepository)
        {
            _mapper = mapper;
            _capPublisher = capPublisher;
            _receiveCaseInfoRepository = receiveCaseInfoRepository;
            _getCaseBackResultRepository = getCaseBackResultRepository;
            _delayCaseResultRepository = delayCaseResultRepository;
            _supplyCaseInfoRepository = supplyCaseInfoRepository;
            _revokeCaseInfoRepository = revokeCaseInfoRepository;
            _remindCaseInfoRepository = remindCaseInfoRepository;
            _sendWarnInfoRepository = sendWarnInfoRepository;
            _sendSuperviseInfoRepository = sendSuperviseInfoRepository;
            _screenCaseResultReceiveRepository = screenCaseResultReceiveRepository;
            _sendCaseEvlResultRepository = sendCaseEvlResultRepository;
            _getCaseReultSendRepository = getCaseReultSendRepository;
            _getVisitInfoSendRepository = getVisitInfoSendRepository;
            _formEnvironMentRepository = formEnvironMentRepository;
            _formTrafficRepository = formTrafficRepository;
            _formExpressWayRepository = formExpressWayRepository;
            _formMedicalRepository = formMedicalRepository;
            _formNetWorktecRepository = formNetWorktecRepository;
            _formPostRepository = formPostRepository;
            _formReturnexChangeRepository = formReturnexChangeRepository;
            _formShamPubRepository = formShamPubRepository;
            _formTaxationComplaintRepository = formTaxationComplaintRepository;
            _formTaxationConsultingRepository = formTaxationConsultingRepository;
            _receiveCaseExtendsRepository = receiveCaseExtendsRepository;
        }
        #endregion

        /// <summary>
        /// 服务工单交办接口
        /// </summary>
        /// <param name="receiveCaseInfo"></param>
        /// <returns></returns>
        [HttpPost("rest/receive_case_info")]
        [AllowAnonymous]
        public async Task<Reponse> ReceiveCaseInfo([FromBody] ReceiveCaseInfoRequest receiveCaseInfo)
        {
            // 验证
            if (receiveCaseInfo is null || receiveCaseInfo.paras is null)
            {
                Reponse.Failed("数据解析失败");
            }

            //验证接收的数据是否正确
            string strResult = receiveCaseInfo.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<ReceiveCaseInfo>(receiveCaseInfo.paras);

            //添加数据
            var id = await _receiveCaseInfoRepository.AddAsync(dto, HttpContext.RequestAborted);

            //处理组装数据，推送数据
            var data = _mapper.Map<OrderDto>(dto);

            //处理性别
            switch (dto.AppLicantSex)
            {
                case "0":
                    data.FromGender = EGender.Female;
                    break;
                case "1":
                    data.FromGender = EGender.Male;
                    break;
                case "2":
                    data.FromGender = EGender.Unknown;
                    break;
                default:
                    data.FromGender = EGender.Unknown;
                    break;
            }

            //处理证件类型
            switch (dto.CertifiCateType)
            {
                case "10":
                    data.LicenceTypeCode = "10";
                    break;
                case "20":
                    data.LicenceTypeCode = "40";
                    break;
                case "30":
                    data.LicenceTypeCode = "55";
                    break;
                case "40":
                    data.LicenceTypeCode = "57";
                    break;
            }

            //处理受理类型
            switch (dto.CaseType)
            {
                case "10":
                    data.AcceptType = EAcceptType.Consult;
                    break;
                case "15":
                    data.AcceptType = EAcceptType.Suggest;
                    break;
                case "20":
                    data.AcceptType = EAcceptType.SeekHelp;
                    break;
                case "25":
                    data.AcceptType = EAcceptType.Praise;
                    break;
                case "30":
                    data.AcceptType = EAcceptType.Report;
                    break;
                case "35":
                    data.AcceptType = EAcceptType.Complain;
                    break;
                case "40":
                    data.AcceptType = EAcceptType.Other;
                    break;
            }

            //处理紧急程度
            switch (dto.CaseIsUrgent)
            {
                case "10":
                    data.EmergencyLevel = EEmergencyLevel.QuiteEmergency;
                    break;
                case "20":
                    data.EmergencyLevel = EEmergencyLevel.Emergency;
                    break;
                case "30":
                    data.EmergencyLevel = EEmergencyLevel.Normal;
                    break;
            }

            //经纬度处理
            var lngLat = dto.CaseLngLat.Split(',');
            if (lngLat != null && lngLat.Length == 2)
            {
                data.Longitude = Convert.ToDouble(lngLat[0]);
                data.Latitude = Convert.ToDouble(lngLat[1]);
            }

            //向业务系统推送消息
            // await _capPublisher.PublishAsync(Hotline.Share.Mq.EventNames.HotlineOrderReceiveCaseInfo, addOrderDto, cancellationToken: HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
                return Reponse.Success("您已成功提交数据！");
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 服务工单退回反馈接口
        /// </summary>
        /// <param name="receiveBackResult">退回反馈</param>
        /// <returns></returns>
        [HttpPost("get_case_back_result")]
        [AllowAnonymous]
        public async Task<Reponse> GetCaseBackResult([FromBody] GetCaseBackResultRequest receiveBackResult)
        {
            // 验证
            if (receiveBackResult is null || receiveBackResult.paras is null)
                Reponse.Failed("数据解析失败");

            //验证接收的数据是否正确
            string strResult = receiveBackResult.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<GetCaseBackResult>(receiveBackResult.paras);

            //添加数据
            var id = await _getCaseBackResultRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderReturnFeedback, _mapper.Map<ReturnFeedbackDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }

            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 服务工单延时审核结果接口
        /// </summary>
        /// <param name="receiveDelayCaseResult">延时审核结果对象</param>
        /// <returns></returns>
        [HttpPost("delay_case_result_receive")]
        [AllowAnonymous]
        public async Task<Reponse> DelayCaseResultReceive([FromBody] DelayCaseResultRequest receiveDelayCaseResult)
        {
            // 验证
            if (receiveDelayCaseResult is null || receiveDelayCaseResult.paras is null)
                Reponse.Failed("数据解析失败");

            string strResult = receiveDelayCaseResult.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<DelayCaseResult>(receiveDelayCaseResult.paras);

            //添加数据
            var id = await _delayCaseResultRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderDelayResult, _mapper.Map<DelayResultDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 服务工单交办补充诉求接口
        /// </summary>
        /// <param name="receiveSupplyCaseInfo">交办补充诉求对象</param>
        /// <returns></returns>
        [HttpPost("supply_case_info_receive")]
        [AllowAnonymous]
        public async Task<Reponse> SupplyCaseInfoReceive([FromBody] SupplyCaseInfoRequest receiveSupplyCaseInfo)
        {
            // 验证
            if (receiveSupplyCaseInfo is null || receiveSupplyCaseInfo.paras is null)
                Reponse.Failed("数据解析失败");

            string strResult = receiveSupplyCaseInfo.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<SupplyCaseInfo>(receiveSupplyCaseInfo.paras);

            //添加数据
            var id = await _supplyCaseInfoRepository.AddAsync(dto, HttpContext.RequestAborted);


            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderSupplements, _mapper.Map<SupplementsDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");

            }
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 服务工单撤单接口
        /// </summary>
        /// <param name="receiveRevokeCaseInfo">撤单对象</param>
        /// <returns></returns>
        [HttpPost("revoke_case_info")]
        [AllowAnonymous]
        public async Task<Reponse> RevokeCaseInfo([FromBody] RevokeCaseInfoRequest receiveRevokeCaseInfo)
        {
            // 验证
            if (receiveRevokeCaseInfo is null || receiveRevokeCaseInfo.paras is null)
                Reponse.Failed("数据解析失败");

            string strResult = receiveRevokeCaseInfo.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<RevokeCaseInfo>(receiveRevokeCaseInfo.paras);
            dto.Direction = "2";
            //添加数据
            var id = await _revokeCaseInfoRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderRevoke, _mapper.Map<RevokeDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 服务工单催单接口
        /// </summary>
        /// <param name="receiveRemindCaseInfo">催单对象</param>
        /// <returns></returns>
        [HttpPost("remind_case_info")]
        [AllowAnonymous]
        public async Task<Reponse> RemindCaseInfo([FromBody] RemindCaseInfoRequest receiveRemindCaseInfo)
        {
            // 验证
            if (receiveRemindCaseInfo is null || receiveRemindCaseInfo.paras is null)
                Reponse.Failed("数据解析失败");

            string strResult = receiveRemindCaseInfo.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<RemindCaseInfo>(receiveRemindCaseInfo.paras);
            dto.Direction = "2";
            //添加数据
            var id = await _remindCaseInfoRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderRemind, _mapper.Map<RemindDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 服务工单预警接口
        /// </summary>
        /// <param name="receiveSendWarnInfo">预警对象</param>
        /// <returns></returns>
        [HttpPost("send_warn_info")]
        [AllowAnonymous]
        public async Task<Reponse> SendWarnInfo([FromBody] SendWarnInfoRequest receiveSendWarnInfo)
        {
            // 验证
            if (receiveSendWarnInfo is null || receiveSendWarnInfo.paras is null)
                Reponse.Failed("数据解析失败");

            string strResult = receiveSendWarnInfo.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<SendWarnInfo>(receiveSendWarnInfo.paras);

            //添加数据
            var id = await _sendWarnInfoRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderWarning, _mapper.Map<WarningDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 督办工单派发接口
        /// </summary>
        /// <param name="receiveSendSuperviseInfo">督办工单对象</param>
        /// <returns></returns>
        [HttpPost("send_supervise_info")]
        [AllowAnonymous]
        public async Task<Reponse> SendSuperviseInfo([FromBody] SendSuperviseInfoRequest receiveSendSuperviseInfo)
        {
            // 验证
            if (receiveSendSuperviseInfo is null || receiveSendSuperviseInfo.paras is null)
                Reponse.Failed("数据解析失败");

            string strResult = receiveSendSuperviseInfo.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<SendSuperviseInfo>(receiveSendSuperviseInfo.paras);

            //添加数据
            var id = await _sendSuperviseInfoRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderSupervise, _mapper.Map<SuperviseDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 服务工单甄别结果接口
        /// </summary>
        /// <param name="receiveScreenCaseResultReceive">服务工单甄别结果对象</param>
        /// <returns></returns>
        [HttpPost("screen_case_result_receive")]
        [AllowAnonymous]
        public async Task<Reponse> ScreenCaseResultReceive([FromBody] ScreenCaseResultReceiveRequest receiveScreenCaseResultReceive)
        {
            // 验证
            if (receiveScreenCaseResultReceive is null || receiveScreenCaseResultReceive.paras is null)
                return Reponse.Failed("数据解析失败");

            string strResult = receiveScreenCaseResultReceive.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                return Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<ScreenCaseResultReceive>(receiveScreenCaseResultReceive.paras);

            //添加数据
            var id = await _screenCaseResultReceiveRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderScreen, _mapper.Map<ScreenDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 交办工单满意度接收接口
        /// </summary>
        /// <param name="receiveSendCaseEvlResult">交办工单满意度对象</param>
        /// <returns></returns>
        [HttpPost("send_case_evl_result")]
        [AllowAnonymous]
        public async Task<Reponse> SendCaseEvlResult([FromBody] SendCaseEvlResultRequest receiveSendCaseEvlResult)
        {
            // 验证
            if (receiveSendCaseEvlResult is null || receiveSendCaseEvlResult.paras is null)
                return Reponse.Failed("数据解析失败");

            string strResult = receiveSendCaseEvlResult.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                return Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<SendCaseEvlResult>(receiveSendCaseEvlResult.paras);

            //添加数据
            var id = await _sendCaseEvlResultRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderEvlResult, _mapper.Map<EvlResultDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 上报工单处理结果/退回接口
        /// </summary>
        /// <param name="receiveGetCaseReultSend">上报工单处理结果/退回对象</param>
        /// <returns></returns>
        [HttpPost]
        [Route("get_case_result_send")]
        public async Task<Reponse> GetCaseReultSend([FromBody] GetCaseReultSendRequest receiveGetCaseReultSend)
        {
            // 验证
            if (receiveGetCaseReultSend is null || receiveGetCaseReultSend.paras is null)
                return Reponse.Failed("数据解析失败");

            string strResult = receiveGetCaseReultSend.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                return Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<GetCaseReultSend>(receiveGetCaseReultSend.paras);

            //添加数据
            var id = await _getCaseReultSendRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderReultSend, _mapper.Map<ReultSendDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 上报工单评价接口
        /// </summary>
        /// <param name="receiveGetVisitInfoSend">上报工单评价对象</param>
        /// <returns></returns>
        [HttpPost]
        [Route("get_visit_info_send")]
        [AllowAnonymous]
        public async Task<Reponse> GetVisitInfoSend([FromBody] GetVisitInfoSendRequest receiveGetVisitInfoSend)
        {
            // 验证
            if (receiveGetVisitInfoSend is null || receiveGetVisitInfoSend.paras is null)
                return Reponse.Failed("数据解析失败");

            string strResult = receiveGetVisitInfoSend.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                return Reponse.Failed(strResult);

            //转换数据
            var dto = _mapper.Map<GetVisitInfoSend>(receiveGetVisitInfoSend.paras);

            //添加数据
            var id = await _getVisitInfoSendRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderVisitInfo, _mapper.Map<VisitInfoDto>(dto), cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }
            else
                return Reponse.Failed("接口调用失败！");
        }

        /// <summary>
        /// 服务工单拓展信息交办
        /// </summary>
        /// <param name="receiveCaseExtendsRequest">服务工单拓展信息交办</param>
        /// <returns></returns>
        [HttpPost]
        [Route("rest/receive_case_extends")]
        [AllowAnonymous]
        public async Task<Reponse> ReceiveCaseExtends([FromBody] ReceiveCaseExtendsRequest receiveCaseExtendsRequest)
        {
            // 验证
            if (receiveCaseExtendsRequest is null || receiveCaseExtendsRequest.paras is null)
                return Reponse.Failed("数据解析失败");

            string strResult = receiveCaseExtendsRequest.paras.Validate();
            if (!string.IsNullOrEmpty(strResult))
                return Reponse.Failed(strResult);

            var data = receiveCaseExtendsRequest.paras;

            //扩展主表信息
            ReceiveCaseExtends receiveCaseExtends = new()
            {
                CaseSerial = data.CaseSerial,
                FormType = data.FormType,
                SyncState = "1",
                Direction = "2"
            };
            var id = await _receiveCaseExtendsRepository.AddAsync(receiveCaseExtends, HttpContext.RequestAborted);
            if (!string.IsNullOrEmpty(id))
                return Reponse.Failed("数据提交失败");

            ReceiveCaseExtendsDto extendsDto = new()
            {
                CaseSerial = data.CaseSerial,
                FormType = data.FormType
            };
            //扩展信息写入
            switch (data.FormType.ToLower())
            {
                case "yl"://医疗表单
                    //转换数据
                    var dtoyl = _mapper.Map<FormMedical>(data.FormMedical);
                    dtoyl.RCEId = id;
                    //添加数据
                    await _formMedicalRepository.AddAsync(dtoyl, HttpContext.RequestAborted);
                    extendsDto.FormMedical = _mapper.Map<FormMedicalInfoDto>(dtoyl);
                    break;
                case "zwfw"://四川政务服务网技术工单
                    //转换数据
                    var dtozwfw = _mapper.Map<FormNetWorktec>(data.FormNetWorktec);
                    dtozwfw.RCEId = id;
                    //添加数据
                    await _formNetWorktecRepository.AddAsync(dtozwfw, HttpContext.RequestAborted);
                    extendsDto.FormNetWorktec = _mapper.Map<FormNetWorktecInfoDto>(dtozwfw);
                    break;
                case "th"://电视购物及商铺购买退换货工单
                    //转换数据
                    var dtoth = _mapper.Map<FormReturnexChange>(data.FormReturnexChange);
                    dtoth.RCEId = id;
                    //添加数据
                    await _formReturnexChangeRepository.AddAsync(dtoth, HttpContext.RequestAborted);
                    extendsDto.FormReturnexChange = _mapper.Map<FormReturnexChangeInfoDto>(dtoth);
                    break;
                case "gsgl"://高速公路工单
                    //转换数据
                    var dtogsgl = _mapper.Map<FormExpressWay>(data.FormExpressWay);
                    dtogsgl.RCEId = id;
                    //添加数据
                    await _formExpressWayRepository.AddAsync(dtogsgl, HttpContext.RequestAborted);
                    extendsDto.FormExpressWay = _mapper.Map<FormExpressWayInfoDto>(dtogsgl);
                    break;
                case "xjgg"://电视台虚假广告工单
                    //转换数据
                    var dtoxjgg = _mapper.Map<FormShamPub>(data.FormShamPub);
                    dtoxjgg.RCEId = id;
                    //添加数据
                    await _formShamPubRepository.AddAsync(dtoxjgg, HttpContext.RequestAborted);
                    extendsDto.FormShamPub = _mapper.Map<FormShamPubInfoDto>(dtoxjgg);
                    break;
                case "swfwsq"://12366热线诉求交办
                    //转换数据
                    var dtoswfwsq = _mapper.Map<FormTaxationComplaint>(data.FormTaxationComplaint);
                    dtoswfwsq.RCEId = id;
                    //添加数据
                    await _formTaxationComplaintRepository.AddAsync(dtoswfwsq, HttpContext.RequestAborted);
                    extendsDto.FormTaxationComplaint = _mapper.Map<FormTaxationComplaintInfoDto>(dtoswfwsq);
                    break;
                case "swfwzx"://12366热线咨询交办
                    //转换数据
                    var dtoswfwzx = _mapper.Map<FormTaxationConsulting>(data.FormTaxationConsulting);
                    dtoswfwzx.RCEId = id;
                    //添加数据
                    await _formTaxationConsultingRepository.AddAsync(dtoswfwzx, HttpContext.RequestAborted);
                    extendsDto.FormTaxationConsulting = _mapper.Map<FormTaxationConsultingInfoDto>(dtoswfwzx);
                    break;
                case "jtfwjd"://12328服务监督
                    //转换数据
                    var dtojtfwjd = _mapper.Map<FormTraffic>(data.FormTraffic);
                    dtojtfwjd.RCEId = id;
                    //添加数据
                    await _formTrafficRepository.AddAsync(dtojtfwjd, HttpContext.RequestAborted);
                    extendsDto.FormTraffic = _mapper.Map<FormTrafficInfoDto>(dtojtfwjd);
                    break;
                case "yzxf"://邮政业消费者申诉
                    //转换数据
                    var dtoyzxf = _mapper.Map<FormPost>(data.FormPost);
                    dtoyzxf.RCEId = id;
                    //添加数据
                    await _formPostRepository.AddAsync(dtoyzxf, HttpContext.RequestAborted);
                    extendsDto.FormPost = _mapper.Map<FormPostInfoDto>(dtoyzxf);
                    break;
                case "hbjb"://环保举报业务
                    //转换数据
                    var dtohbjb = _mapper.Map<FormEnvironMent>(data.FormEnvironMent);
                    dtohbjb.RCEId = id;
                    //添加数据
                    await _formEnvironMentRepository.AddAsync(dtohbjb, HttpContext.RequestAborted);
                    extendsDto.FormEnvironMent = _mapper.Map<FormEnvironMentInfoDto>(dtohbjb);
                    break;
                case "scjgj"://12315个性化表单
                    break;
                default:
                    break;
            }

            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingOrderExtends, extendsDto, cancellationToken: HttpContext.RequestAborted);
                return Reponse.Success("您已成功提交数据！");
            }
            else
                return Reponse.Failed("接口调用失败！");
        }


        //还缺附件的
    }
}
